@@ -21,7 +21,7 @@ plt.scatter(x, y, s=80, c=z, marker=">")
 plt.subplot(322)
 plt.scatter(x, y, s=80, c=z, marker=(5, 0))
 
-verts = list(zip([-1., 1., 1., -1.], [-1., -1., 1., -1.]))
+verts = np.array([[-1, -1], [1, -1], [1, 1], [-1, -1]])
 plt.subplot(323)
 plt.scatter(x, y, s=80, c=z, marker=(verts, 0))
 # equivalent:
