@@ -18,8 +18,7 @@ dates, closes = np.loadtxt(datafile, delimiter=',',
                            converters={0: bytespdate2num('%d-%b-%y')},
                            skiprows=1, usecols=(0, 2), unpack=True)
 
-fig = plt.figure()
-ax = fig.add_subplot(111)
+fig, ax = plt.subplots()
 ax.plot_date(dates, closes, '-')
 fig.autofmt_xdate()
 plt.show()
