@@ -11,7 +11,7 @@ Example contributed by Armin Moser.
 '''
 
 from mpl_toolkits.mplot3d import Axes3D
-from matplotlib import pyplot as plt
+import matplotlib.pyplot as plt
 import numpy as np
 
 
