@@ -1,9 +1,23 @@
+"""
+============================
+Bachelor's degrees by gender
+============================
+
+A graph of multiple time series which demonstrates extensive custom
+styling of plot frame, tick lines and labels, and line graph properties.
+
+Also demonstrates the custom placement of text labels along the right edge
+as an alternative to a conventional legend.
+"""
+
+import numpy as np
 import matplotlib.pyplot as plt
-from matplotlib.mlab import csv2rec
 from matplotlib.cbook import get_sample_data
 
-fname = get_sample_data('percent_bachelors_degrees_women_usa.csv')
-gender_degree_data = csv2rec(fname)
+
+fname = get_sample_data('percent_bachelors_degrees_women_usa.csv',
+                        asfileobj=False)
+gender_degree_data = np.genfromtxt(fname, delimiter=',', names=True)
 
 # These are the colors that will be used in the plot
 color_sequence = ['#1f77b4', '#aec7e8', '#ff7f0e', '#ffbb78', '#2ca02c',
@@ -27,28 +41,28 @@ ax.spines['left'].set_visible(False)
 ax.get_xaxis().tick_bottom()
 ax.get_yaxis().tick_left()
 
+fig.subplots_adjust(left=.06, right=.75, bottom=.02, top=.94)
 # Limit the range of the plot to only where the data is.
 # Avoid unnecessary whitespace.
-plt.xlim(1968.5, 2011.1)
-plt.ylim(-0.25, 90)
+ax.set_xlim(1969.5, 2011.1)
+ax.set_ylim(-0.25, 90)
 
 # Make sure your axis ticks are large enough to be easily read.
 # You don't want your viewers squinting to read your plot.
 plt.xticks(range(1970, 2011, 10), fontsize=14)
-plt.yticks(range(0, 91, 10), ['{0}%'.format(x)
-                              for x in range(0, 91, 10)], fontsize=14)
+plt.yticks(range(0, 91, 10), fontsize=14)
+ax.xaxis.set_major_formatter(plt.FuncFormatter('{:.0f}'.format))
+ax.yaxis.set_major_formatter(plt.FuncFormatter('{:.0f}%'.format))
 
 # Provide tick lines across the plot to help your viewers trace along
 # the axis ticks. Make sure that the lines are light and small so they
 # don't obscure the primary data lines.
-for y in range(10, 91, 10):
-    plt.plot(range(1969, 2012), [y] * len(range(1969, 2012)), '--',
-             lw=0.5, color='black', alpha=0.3)
+plt.grid(True, 'major', 'y', ls='--', lw=.5, c='k', alpha=.3)
 
 # Remove the tick marks; they are unnecessary with the tick lines we just
 # plotted.
-plt.tick_params(axis='both', which='both', bottom='off', top='off',
-                labelbottom='on', left='off', right='off', labelleft='on')
+plt.tick_params(axis='both', which='both', bottom=False, top=False,
+                labelbottom=True, left=False, right=False, labelleft=True)
 
 # Now that the plot is prepared, it's time to actually plot the data!
 # Note that I plotted the majors in order of the highest % in the final year.
@@ -68,9 +82,9 @@ y_offsets = {'Foreign Languages': 0.5, 'English': -0.5,
 
 for rank, column in enumerate(majors):
     # Plot each line separately with its own color.
-    column_rec_name = column.replace('\n', '_').replace(' ', '_').lower()
+    column_rec_name = column.replace('\n', '_').replace(' ', '_')
 
-    line = plt.plot(gender_degree_data.year,
+    line = plt.plot(gender_degree_data['Year'],
                     gender_degree_data[column_rec_name],
                     lw=2.5,
                     color=color_sequence[rank])
@@ -91,10 +105,11 @@ for rank, column in enumerate(majors):
 
 # Note that if the title is descriptive enough, it is unnecessary to include
 # axis labels; they are self-evident, in this plot's case.
-plt.title('Percentage of Bachelor\'s degrees conferred to women in '
-          'the U.S.A. by major (1970-2011)\n', fontsize=18, ha='center')
+fig.suptitle('Percentage of Bachelor\'s degrees conferred to women in '
+             'the U.S.A. by major (1970-2011)\n', fontsize=18, ha='center')
 
 # Finally, save the figure as a PNG.
 # You can also save it as a PDF, JPEG, etc.
 # Just change the file extension in this call.
-plt.savefig('percent-bachelors-degrees-women-usa.png', bbox_inches='tight')
+# plt.savefig('percent-bachelors-degrees-women-usa.png', bbox_inches='tight')
+plt.show()
