@@ -18,6 +18,7 @@ plt.subplots_adjust(left=0.25, bottom=0.25)
 t = np.arange(0.0, 1.0, 0.001)
 a0 = 5
 f0 = 3
+delta_f = 5.0
 s = a0*np.sin(2*np.pi*f0*t)
 l, = plt.plot(t, s, lw=2, color='red')
 plt.axis([0, 1, -10, 10])
@@ -26,7 +27,7 @@ axcolor = 'lightgoldenrodyellow'
 axfreq = plt.axes([0.25, 0.1, 0.65, 0.03], facecolor=axcolor)
 axamp = plt.axes([0.25, 0.15, 0.65, 0.03], facecolor=axcolor)
 
-sfreq = Slider(axfreq, 'Freq', 0.1, 30.0, valinit=f0)
+sfreq = Slider(axfreq, 'Freq', 0.1, 30.0, valinit=f0, valstep=delta_f)
 samp = Slider(axamp, 'Amp', 0.1, 10.0, valinit=a0)
 
 
