@@ -19,7 +19,8 @@ It is pretty easy to use, and requires only built-in python libs:
     ...                         'fonts', 'afm', 'ptmr8a.afm')
     >>>
     >>> from matplotlib.afm import AFM
-    >>> afm = AFM(open(afm_fname))
+    >>> with open(afm_fname, 'rb') as fh:
+    ...     afm = AFM(fh)
     >>> afm.string_width_height('What the heck?')
     (6220.0, 694)
     >>> afm.get_fontname()
@@ -36,11 +37,10 @@ It is pretty easy to use, and requires only built-in python libs:
 from __future__ import (absolute_import, division, print_function,
                         unicode_literals)
 
-from matplotlib.externals import six
-from matplotlib.externals.six.moves import map
+import six
+from six.moves import map
 
 import sys
-import os
 import re
 from ._mathtext_data import uni2type1
 
@@ -56,12 +56,12 @@ from ._mathtext_data import uni2type1
 def _to_int(x):
     return int(float(x))
 
+
 _to_float = float
-if six.PY3:
-    def _to_str(x):
-        return x.decode('utf8')
-else:
-    _to_str = str
+
+
+def _to_str(x):
+    return x.decode('utf8')
 
 
 def _to_list_of_ints(s):
@@ -90,7 +90,7 @@ def _sanity_check(fh):
     # do something else with the file.
     pos = fh.tell()
     try:
-        line = fh.readline()
+        line = next(fh)
     finally:
         fh.seek(pos, 0)
 
@@ -147,10 +147,7 @@ def _parse_header(fh):
         }
 
     d = {}
-    while 1:
-        line = fh.readline()
-        if not line:
-            break
+    for line in fh:
         line = line.rstrip()
         if line.startswith(b'Comment'):
             continue
@@ -190,18 +187,16 @@ def _parse_char_metrics(fh):
 
     ascii_d = {}
     name_d = {}
-    while 1:
-        line = fh.readline()
-        if not line:
-            break
-        line = line.rstrip().decode('ascii')  # Convert from byte-literal
+    for line in fh:
+        # We are defensively letting values be utf8. The spec requires
+        # ascii, but there are non-compliant fonts in circulation
+        line = _to_str(line.rstrip())  # Convert from byte-literal
         if line.startswith('EndCharMetrics'):
             return ascii_d, name_d
-        # Split the metric line into a dictonary, keyed by metric identifiers
-        vals = filter(lambda s: len(s) > 0, line.split(';'))
-        vals = dict(map(lambda s: tuple(s.strip().split(' ', 1)), vals))
+        # Split the metric line into a dictionary, keyed by metric identifiers
+        vals = dict(s.strip().split(' ', 1) for s in line.split(';') if s)
         # There may be other metrics present, but only these are needed
-        if any([id not in vals.keys() for id in ('C', 'WX', 'N', 'B')]):
+        if not {'C', 'WX', 'N', 'B'}.issubset(vals):
             raise RuntimeError('Bad char metrics line: %s' % line)
         num = _to_int(vals['C'])
         wx = _to_float(vals['WX'])
@@ -231,20 +226,17 @@ def _parse_kern_pairs(fh):
 
     """
 
-    line = fh.readline()
+    line = next(fh)
     if not line.startswith(b'StartKernPairs'):
         raise RuntimeError('Bad start of kern pairs data: %s' % line)
 
     d = {}
-    while 1:
-        line = fh.readline()
-        if not line:
-            break
+    for line in fh:
         line = line.rstrip()
-        if len(line) == 0:
+        if not line:
             continue
         if line.startswith(b'EndKernPairs'):
-            fh.readline()  # EndKernData
+            next(fh)  # EndKernData
             return d
         vals = line.split()
         if len(vals) != 4 or vals[0] != b'KPX':
@@ -269,12 +261,9 @@ def _parse_composites(fh):
 
     """
     d = {}
-    while 1:
-        line = fh.readline()
-        if not line:
-            break
+    for line in fh:
         line = line.rstrip()
-        if len(line) == 0:
+        if not line:
             continue
         if line.startswith(b'EndComposites'):
             return d
@@ -306,12 +295,9 @@ def _parse_optional(fh):
         }
 
     d = {b'StartKernData': {}, b'StartComposites': {}}
-    while 1:
-        line = fh.readline()
-        if not line:
-            break
+    for line in fh:
         line = line.rstrip()
-        if len(line) == 0:
+        if not line:
             continue
         key = line.split()[0]
 
@@ -325,11 +311,13 @@ def _parse_optional(fh):
 def parse_afm(fh):
     """
     Parse the Adobe Font Metics file in file handle *fh*. Return value
-    is a (*dhead*, *dcmetrics*, *dkernpairs*, *dcomposite*) tuple where
-    *dhead* is a :func:`_parse_header` dict, *dcmetrics* is a
-    :func:`_parse_composites` dict, *dkernpairs* is a
-    :func:`_parse_kern_pairs` dict (possibly {}), and *dcomposite* is a
-    :func:`_parse_composites` dict (possibly {})
+    is a (*dhead*, *dcmetrics_ascii*, *dmetrics_name*, *dkernpairs*,
+    *dcomposite*) tuple where
+    *dhead* is a :func:`_parse_header` dict,
+    *dcmetrics_ascii* and *dcmetrics_name* are the two resulting dicts
+    from :func:`_parse_char_metrics`,
+    *dkernpairs* is a :func:`_parse_kern_pairs` dict (possibly {}) and
+    *dcomposite* is a :func:`_parse_composites` dict (possibly {})
     """
     _sanity_check(fh)
     dhead = _parse_header(fh)
@@ -407,7 +395,7 @@ class AFM(object):
         maxy = 0
         left = 0
         if not isinstance(s, six.text_type):
-            s = s.decode('ascii')
+            s = _to_str(s)
         for c in s:
             if c == '\n':
                 continue
@@ -495,10 +483,7 @@ class AFM(object):
         Return the kerning pair distance (possibly 0) for chars
         *name1* and *name2*
         """
-        try:
-            return self._kern[(name1, name2)]
-        except:
-            return 0
+        return self._kern.get((name1, name2), 0)
 
     def get_fontname(self):
         "Return the font name, e.g., 'Times-Roman'"
@@ -519,10 +504,14 @@ class AFM(object):
 
         # FamilyName not specified so we'll make a guess
         name = self.get_fullname()
-        extras = (br'(?i)([ -](regular|plain|italic|oblique|bold|semibold|'
-                  br'light|ultralight|extra|condensed))+$')
+        extras = (r'(?i)([ -](regular|plain|italic|oblique|bold|semibold|'
+                  r'light|ultralight|extra|condensed))+$')
         return re.sub(extras, '', name)
 
+    @property
+    def family_name(self):
+        return self.get_familyname()
+
     def get_weight(self):
         "Return the font weight, e.g., 'Bold' or 'Roman'"
         return self._header[b'Weight']
