@@ -472,11 +472,13 @@ class FigureManagerTk(FigureManagerBase):
         self.window.withdraw()
         self.set_window_title("Figure %d" % num)
         self.canvas = canvas
+        # If using toolmanager it has to be present when initializing the toolbar
+        self.toolmanager = self._get_toolmanager()
+        # packing toolbar first, because if space is getting low, last packed widget is getting shrunk first (-> the canvas)
+        self.toolbar = self._get_toolbar()
         self.canvas._tkcanvas.pack(side=Tk.TOP, fill=Tk.BOTH, expand=1)
         self._num = num
 
-        self.toolmanager = self._get_toolmanager()
-        self.toolbar = self._get_toolbar()
         self.statusbar = None
 
         if self.toolmanager:
@@ -1052,7 +1054,7 @@ class _BackendTk(_Backend):
             rcParams['datapath'], 'images', 'matplotlib.ppm')
         icon_img = Tk.PhotoImage(file=icon_fname)
         try:
-            window.tk.call('wm', 'foobar', window._w, icon_img)
+            window.tk.call('wm', 'iconphoto', window._w, icon_img)
         except Exception as exc:
             # log the failure (due e.g. to Tk version), but carry on
             _log.info('Could not load matplotlib icon: %s', exc)
