@@ -24,13 +24,19 @@ from __future__ import (absolute_import, division, print_function,
 
 import six
 
-import threading
+try:
+    import threading
+except ImportError:
+    import dummy_threading as threading
+
 import numpy as np
 from collections import OrderedDict
 from math import radians, cos, sin
 from matplotlib import cbook, rcParams, __version__
 from matplotlib.backend_bases import (
     _Backend, FigureCanvasBase, FigureManagerBase, RendererBase, cursors)
+from matplotlib.cbook import maxdict
+from matplotlib.figure import Figure
 from matplotlib.font_manager import findfont, get_font
 from matplotlib.ft2font import (LOAD_FORCE_AUTOHINT, LOAD_NO_HINTING,
                                 LOAD_DEFAULT, LOAD_NO_AUTOHINT)
