@@ -10,13 +10,16 @@
 #===========================================================================
 # Place all imports after here.
 #
-from __future__ import print_function
+from __future__ import (absolute_import, division, print_function,
+                        unicode_literals)
+
+import six
 #
 # Place all imports before here.
 #===========================================================================
 
 #===========================================================================
-class Duration:
+class Duration(object):
    """Class Duration in development.
    """
    allowed = [ "ET", "UTC" ]
@@ -72,6 +75,9 @@ class Duration:
       """
       return self._seconds != 0
 
+   if six.PY3:
+      __bool__ = __nonzero__
+
    #-----------------------------------------------------------------------
    def __cmp__( self, rhs ):
       """Compare two Durations.
@@ -160,7 +166,7 @@ class Duration:
       = RETURN VALUE
       - Returns the scaled Duration.
       """
-      return Duration( self._frame, self._seconds / float( rhs ) )
+      return Duration( self._frame, self._seconds / rhs )
 
    #-----------------------------------------------------------------------
    def __rdiv__( self, rhs ):
@@ -172,7 +178,7 @@ class Duration:
       = RETURN VALUE
       - Returns the scaled Duration.
       """
-      return Duration( self._frame, float( rhs ) / self._seconds )
+      return Duration( self._frame, rhs / self._seconds )
 
    #-----------------------------------------------------------------------
    def __str__( self ):
