@@ -10,7 +10,11 @@
 #===========================================================================
 # Place all imports after here.
 #
-from __future__ import print_function
+from __future__ import (absolute_import, division, print_function,
+                        unicode_literals)
+
+import six
+
 import matplotlib.ticker as ticker
 #
 # Place all imports before here.
@@ -32,12 +36,12 @@ class UnitDblFormatter( ticker.ScalarFormatter ):
       if len(self.locs) == 0:
          return ''
       else:
-         return str(x)
+         return '{:.12}'.format(x)
 
    def format_data_short( self, value ):
       "Return the value formatted in 'short' format."
-      return str(value)
+      return '{:.12}'.format(value)
 
    def format_data( self, value ):
       "Return the value formatted into a string."
-      return str(value)
+      return '{:.12}'.format(value)
