@@ -1,7 +1,6 @@
 # -*- coding: utf-8 -*-
 
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
+from __future__ import absolute_import, division, print_function
 
 import io
 import re
@@ -13,6 +12,7 @@ import six
 import matplotlib
 import matplotlib.pyplot as plt
 from matplotlib import patheffects
+from matplotlib.testing.decorators import image_comparison
 from matplotlib.testing.determinism import (_determinism_source_date_epoch,
                                             _determinism_check)
 
@@ -59,7 +59,7 @@ def test_savefig_to_stringio(format, use_log, rcParams):
         ax.set_yscale('log')
 
     ax.plot([1, 2], [1, 2])
-    ax.set_title("Déjà vu")
+    ax.set_title(u"Déjà vu")
     for buffer in buffers:
         fig.savefig(buffer, format=format)
 
@@ -81,30 +81,6 @@ def test_savefig_to_stringio(format, use_log, rcParams):
         buffer.close()
 
 
-def test_composite_image():
-    # Test that figures can be saved with and without combining multiple images
-    # (on a single set of axes) into a single composite image.
-    X, Y = np.meshgrid(np.arange(-5, 5, 1), np.arange(-5, 5, 1))
-    Z = np.sin(Y ** 2)
-    fig = plt.figure()
-    ax = fig.add_subplot(1, 1, 1)
-    ax.set_xlim(0, 3)
-    ax.imshow(Z, extent=[0, 1, 0, 1])
-    ax.imshow(Z[::-1], extent=[2, 3, 0, 1])
-    plt.rcParams['image.composite_image'] = True
-    with io.BytesIO() as ps:
-        fig.savefig(ps, format="ps")
-        ps.seek(0)
-        buff = ps.read()
-        assert buff.count(six.b(' colorimage')) == 1
-    plt.rcParams['image.composite_image'] = False
-    with io.BytesIO() as ps:
-        fig.savefig(ps, format="ps")
-        ps.seek(0)
-        buff = ps.read()
-        assert buff.count(six.b(' colorimage')) == 2
-
-
 def test_patheffects():
     with matplotlib.rc_context():
         matplotlib.rcParams['path.effects'] = [
@@ -118,7 +94,7 @@ def test_patheffects():
 @needs_usetex
 @needs_ghostscript
 def test_tilde_in_tempfilename():
-    # Tilde ~ in the tempdir path (e.g. TMPDIR, TMP oder TEMP on windows
+    # Tilde ~ in the tempdir path (e.g. TMPDIR, TMP or TEMP on windows
     # when the username is very long and windows uses a short name) breaks
     # latex before https://github.com/matplotlib/matplotlib/pull/5928
     import tempfile
@@ -140,7 +116,6 @@ def test_tilde_in_tempfilename():
         plt.rc('text', usetex=True)
         plt.plot([1, 2, 3, 4])
         plt.xlabel(r'\textbf{time} (s)')
-        # matplotlib.verbose.set_level("debug")
         output_eps = os.path.join(base_tempdir, 'tex_demo.eps')
         # use the PS backend to write the file...
         plt.savefig(output_eps, format="ps")
@@ -150,7 +125,7 @@ def test_tilde_in_tempfilename():
             try:
                 shutil.rmtree(tempdir)
             except Exception as e:
-                # do not break if this is not removeable...
+                # do not break if this is not removable...
                 print(e)
 
 
@@ -174,3 +149,24 @@ def test_determinism_all():
 def test_determinism_all_tex():
     """Test for reproducible PS/tex output"""
     _determinism_check(format="ps", usetex=True)
+
+
+@image_comparison(baseline_images=["empty"], extensions=["eps"])
+def test_transparency():
+    fig, ax = plt.subplots()
+    ax.set_axis_off()
+    ax.plot([0, 1], color="r", alpha=0)
+    ax.text(.5, .5, "foo", color="r", alpha=0)
+
+
+@needs_usetex
+def test_failing_latex(tmpdir):
+    """Test failing latex subprocess call"""
+    path = str(tmpdir.join("tmpoutput.ps"))
+
+    matplotlib.rcParams['text.usetex'] = True
+
+    # This fails with "Double subscript"
+    plt.xlabel("$22_2_2$")
+    with pytest.raises(RuntimeError):
+        plt.savefig(path)
