@@ -1,5 +1,4 @@
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
+from __future__ import absolute_import, division, print_function
 
 try:
     # mock in python 3.3+
@@ -42,9 +41,14 @@ def get_docstring_section(func, section):
 
 
 def test_legend_kwdocstrings():
-    stleg = get_docstring_section(mpl.legend.Legend.__init__, 'Parameters')
     stax = get_docstring_section(mpl.axes.Axes.legend, 'Parameters')
     stfig = get_docstring_section(mpl.figure.Figure.legend, 'Parameters')
+    assert stfig == stax
+
+    stleg = get_docstring_section(mpl.legend.Legend.__init__,
+                                  'Other Parameters')
+    stax = get_docstring_section(mpl.axes.Axes.legend, 'Other Parameters')
+    stfig = get_docstring_section(mpl.figure.Figure.legend, 'Other Parameters')
     assert stleg == stax
     assert stfig == stax
     assert stleg == stfig
@@ -108,7 +112,7 @@ def test_various_labels():
     fig = plt.figure()
     ax = fig.add_subplot(121)
     ax.plot(np.arange(4), 'o', label=1)
-    ax.plot(np.linspace(4, 4.1), 'o', label='D\xe9velopp\xe9s')
+    ax.plot(np.linspace(4, 4.1), 'o', label=u'D\xe9velopp\xe9s')
     ax.plot(np.arange(4, 1, -1), 'o', label='__nolegend__')
     ax.legend(numpoints=1, loc=0)
 
