@@ -158,11 +158,7 @@ class RendererAgg
     void draw_image(GCAgg &gc,
                     double x,
                     double y,
-                    ImageArray &image,
-                    double w,
-                    double h,
-                    agg::trans_affine trans,
-                    bool resize);
+                    ImageArray &image);
 
     template <class PathGenerator,
               class TransformArray,
@@ -186,8 +182,8 @@ class RendererAgg
     template <class CoordinateArray, class OffsetArray, class ColorArray>
     void draw_quad_mesh(GCAgg &gc,
                         agg::trans_affine &master_transform,
-                        size_t mesh_width,
-                        size_t mesh_height,
+                        unsigned int mesh_width,
+                        unsigned int mesh_height,
                         CoordinateArray &coordinates,
                         OffsetArray &offsets,
                         agg::trans_affine &offset_trans,
@@ -243,8 +239,8 @@ class RendererAgg
     void *lastclippath;
     agg::trans_affine lastclippath_transform;
 
-    static const size_t HATCH_SIZE = 72;
-    agg::int8u hatchBuffer[HATCH_SIZE * HATCH_SIZE * 4];
+    size_t hatch_size;
+    agg::int8u *hatchBuffer;
     agg::rendering_buffer hatchRenderingBuffer;
 
     agg::rgba _fill_color;
@@ -363,11 +359,11 @@ RendererAgg::_draw_path(path_t &path, bool has_clippath, const facepair_t &face,
         agg::trans_affine hatch_trans;
         hatch_trans *= agg::trans_affine_scaling(1.0, -1.0);
         hatch_trans *= agg::trans_affine_translation(0.0, 1.0);
-        hatch_trans *= agg::trans_affine_scaling(HATCH_SIZE, HATCH_SIZE);
+        hatch_trans *= agg::trans_affine_scaling(hatch_size, hatch_size);
         hatch_path_trans_t hatch_path_trans(hatch_path, hatch_trans);
         hatch_path_curve_t hatch_path_curve(hatch_path_trans);
         hatch_path_stroke_t hatch_path_stroke(hatch_path_curve);
-        hatch_path_stroke.width(1.0);
+        hatch_path_stroke.width(points_to_pixels(gc.hatch_linewidth));
         hatch_path_stroke.line_cap(agg::square_cap);
 
         // Render the path into the hatch buffer
@@ -375,7 +371,7 @@ RendererAgg::_draw_path(path_t &path, bool has_clippath, const facepair_t &face,
         renderer_base rb(hatch_img_pixf);
         renderer_aa rs(rb);
         rb.clear(_fill_color);
-        rs.color(gc.color);
+        rs.color(gc.hatch_color);
 
         theRasterizer.add_path(hatch_path_curve);
         agg::render_scanlines(theRasterizer, slineP8, rs);
@@ -488,7 +484,7 @@ RendererAgg::draw_path(GCAgg &gc, PathIterator &path, agg::trans_affine &trans,
 
     transformed_path_t tpath(path, trans);
     nan_removed_t nan_removed(tpath, true, path.has_curves());
-    clipped_t clipped(nan_removed, clip, width, height);
+    clipped_t clipped(nan_removed, clip && !path.has_curves(), width, height);
     snapped_t snapped(clipped, gc.snap_mode, path.total_vertices(), snapping_linewidth);
     simplify_t simplified(snapped, simplify, path.simplify_threshold());
     curve_t curve(simplified);
@@ -744,39 +740,65 @@ inline void RendererAgg::draw_text_image(GCAgg &gc, ImageArray &image, int x, in
 
     theRasterizer.reset_clipping();
     rendererBase.reset_clipping(true);
-    set_clipbox(gc.cliprect, theRasterizer);
+    if (angle != 0.0) {
+        agg::rendering_buffer srcbuf(
+                image.data(), (unsigned)image.dim(1),
+                (unsigned)image.dim(0), (unsigned)image.dim(1));
+        agg::pixfmt_gray8 pixf_img(srcbuf);
 
-    agg::rendering_buffer srcbuf(
-        image.data(), (unsigned)image.dim(1), (unsigned)image.dim(0), (unsigned)image.dim(1));
-    agg::pixfmt_gray8 pixf_img(srcbuf);
+        set_clipbox(gc.cliprect, theRasterizer);
 
-    agg::trans_affine mtx;
-    mtx *= agg::trans_affine_translation(0, -image.dim(0));
-    mtx *= agg::trans_affine_rotation(-angle * agg::pi / 180.0);
-    mtx *= agg::trans_affine_translation(x, y);
+        agg::trans_affine mtx;
+        mtx *= agg::trans_affine_translation(0, -image.dim(0));
+        mtx *= agg::trans_affine_rotation(-angle * agg::pi / 180.0);
+        mtx *= agg::trans_affine_translation(x, y);
 
-    agg::path_storage rect;
-    rect.move_to(0, 0);
-    rect.line_to(image.dim(1), 0);
-    rect.line_to(image.dim(1), image.dim(0));
-    rect.line_to(0, image.dim(0));
-    rect.line_to(0, 0);
-    agg::conv_transform<agg::path_storage> rect2(rect, mtx);
+        agg::path_storage rect;
+        rect.move_to(0, 0);
+        rect.line_to(image.dim(1), 0);
+        rect.line_to(image.dim(1), image.dim(0));
+        rect.line_to(0, image.dim(0));
+        rect.line_to(0, 0);
+        agg::conv_transform<agg::path_storage> rect2(rect, mtx);
 
-    agg::trans_affine inv_mtx(mtx);
-    inv_mtx.invert();
+        agg::trans_affine inv_mtx(mtx);
+        inv_mtx.invert();
 
-    agg::image_filter_lut filter;
-    filter.calculate(agg::image_filter_spline36());
-    interpolator_type interpolator(inv_mtx);
-    color_span_alloc_type sa;
-    image_accessor_type ia(pixf_img, agg::gray8(0));
-    image_span_gen_type image_span_generator(ia, interpolator, filter);
-    span_gen_type output_span_generator(&image_span_generator, gc.color);
-    renderer_type ri(rendererBase, sa, output_span_generator);
+        agg::image_filter_lut filter;
+        filter.calculate(agg::image_filter_spline36());
+        interpolator_type interpolator(inv_mtx);
+        color_span_alloc_type sa;
+        image_accessor_type ia(pixf_img, agg::gray8(0));
+        image_span_gen_type image_span_generator(ia, interpolator, filter);
+        span_gen_type output_span_generator(&image_span_generator, gc.color);
+        renderer_type ri(rendererBase, sa, output_span_generator);
 
-    theRasterizer.add_path(rect2);
-    agg::render_scanlines(theRasterizer, slineP8, ri);
+        theRasterizer.add_path(rect2);
+        agg::render_scanlines(theRasterizer, slineP8, ri);
+    } else {
+        agg::rect_i fig, text;
+
+        fig.init(0, 0, width, height);
+        text.init(x, y - image.dim(0), x + image.dim(1), y);
+        text.clip(fig);
+
+        if (gc.cliprect.x1 != 0.0 || gc.cliprect.y1 != 0.0 || gc.cliprect.x2 != 0.0 || gc.cliprect.y2 != 0.0) {
+            agg::rect_i clip;
+
+            clip.init(int(mpl_round(gc.cliprect.x1)),
+                      int(mpl_round(height - gc.cliprect.y2)),
+                      int(mpl_round(gc.cliprect.x2)),
+                      int(mpl_round(height - gc.cliprect.y1)));
+            text.clip(clip);
+        }
+
+        if (text.x2 > text.x1) {
+            for (int yi = text.y1; yi < text.y2; ++yi) {
+                pixFmt.blend_solid_hspan(text.x1, yi, (text.x2 - text.x1), gc.color,
+                                         &image(yi - (y - image.dim(0)), text.x1 - x));
+            }
+        }
+    }
 }
 
 class span_conv_alpha
@@ -806,11 +828,7 @@ template <class ImageArray>
 inline void RendererAgg::draw_image(GCAgg &gc,
                                     double x,
                                     double y,
-                                    ImageArray &image,
-                                    double w,
-                                    double h,
-                                    agg::trans_affine trans,
-                                    bool resize)
+                                    ImageArray &image)
 {
     double alpha = gc.alpha;
 
@@ -824,21 +842,11 @@ inline void RendererAgg::draw_image(GCAgg &gc,
         image.data(), (unsigned)image.dim(1), (unsigned)image.dim(0), -(int)image.dim(1) * 4);
     pixfmt pixf(buffer);
 
-    if (resize | has_clippath) {
+    if (has_clippath) {
         agg::trans_affine mtx;
         agg::path_storage rect;
 
-        if (resize) {
-            mtx *= agg::trans_affine_scaling(1, -1);
-            mtx *= agg::trans_affine_translation(0, image.dim(0));
-            mtx *= agg::trans_affine_scaling(w / (image.dim(1)), h / (image.dim(0)));
-            mtx *= agg::trans_affine_translation(x, y);
-            mtx *= trans;
-            mtx *= agg::trans_affine_scaling(1.0, -1.0);
-            mtx *= agg::trans_affine_translation(0.0, (double)height);
-        } else {
-            mtx *= agg::trans_affine_translation((int)x, (int)(height - (y + image.dim(0))));
-        }
+        mtx *= agg::trans_affine_translation((int)x, (int)(height - (y + image.dim(0))));
 
         rect.move_to(0, 0);
         rect.line_to(image.dim(1), 0);
@@ -865,30 +873,17 @@ inline void RendererAgg::draw_image(GCAgg &gc,
         span_conv_alpha conv_alpha(alpha);
         span_conv spans(image_span_generator, conv_alpha);
 
-        if (has_clippath) {
-            typedef agg::pixfmt_amask_adaptor<pixfmt, alpha_mask_type> pixfmt_amask_type;
-            typedef agg::renderer_base<pixfmt_amask_type> amask_ren_type;
-            typedef agg::renderer_scanline_aa<amask_ren_type, color_span_alloc_type, span_conv>
+        typedef agg::pixfmt_amask_adaptor<pixfmt, alpha_mask_type> pixfmt_amask_type;
+        typedef agg::renderer_base<pixfmt_amask_type> amask_ren_type;
+        typedef agg::renderer_scanline_aa<amask_ren_type, color_span_alloc_type, span_conv>
             renderer_type_alpha;
 
-            pixfmt_amask_type pfa(pixFmt, alphaMask);
-            amask_ren_type r(pfa);
-            renderer_type_alpha ri(r, sa, spans);
-
-            theRasterizer.add_path(rect2);
-            agg::render_scanlines(theRasterizer, scanlineAlphaMask, ri);
-        } else {
-            typedef agg::renderer_base<pixfmt> ren_type;
-            typedef agg::renderer_scanline_aa<ren_type, color_span_alloc_type, span_conv>
-            renderer_type;
-
-            ren_type r(pixFmt);
-            renderer_type ri(r, sa, spans);
-
-            theRasterizer.add_path(rect2);
-            agg::render_scanlines(theRasterizer, slineP8, ri);
-        }
+        pixfmt_amask_type pfa(pixFmt, alphaMask);
+        amask_ren_type r(pfa);
+        renderer_type_alpha ri(r, sa, spans);
 
+        theRasterizer.add_path(rect2);
+        agg::render_scanlines(theRasterizer, scanlineAlphaMask, ri);
     } else {
         set_clipbox(gc.cliprect, rendererBase);
         rendererBase.blend_from(
@@ -961,13 +956,13 @@ inline void RendererAgg::_draw_path_collection_generic(GCAgg &gc,
         typename PathGenerator::path_iterator path = path_generator(i);
 
         if (Ntransforms) {
-            typename TransformArray::sub_t subtrans = transforms[i % Ntransforms];
-            trans = agg::trans_affine(subtrans(0, 0),
-                                      subtrans(1, 0),
-                                      subtrans(0, 1),
-                                      subtrans(1, 1),
-                                      subtrans(0, 2),
-                                      subtrans(1, 2));
+            int it = i % Ntransforms;
+            trans = agg::trans_affine(transforms(it, 0, 0),
+                                      transforms(it, 1, 0),
+                                      transforms(it, 0, 1),
+                                      transforms(it, 1, 1),
+                                      transforms(it, 0, 2),
+                                      transforms(it, 1, 2));
             trans *= master_transform;
         } else {
             trans = master_transform;
@@ -989,13 +984,13 @@ inline void RendererAgg::_draw_path_collection_generic(GCAgg &gc,
         trans *= agg::trans_affine_translation(0.0, (double)height);
 
         if (Nfacecolors) {
-            typename ColorArray::sub_t facecolor = facecolors[i % Nfacecolors];
-            face.second = agg::rgba(facecolor(0), facecolor(1), facecolor(2), facecolor(3));
+            int ic = i % Nfacecolors;
+            face.second = agg::rgba(facecolors(ic, 0), facecolors(ic, 1), facecolors(ic, 2), facecolors(ic, 3));
         }
 
         if (Nedgecolors) {
-            typename ColorArray::sub_t edgecolor = edgecolors[i % Nedgecolors];
-            gc.color = agg::rgba(edgecolor(0), edgecolor(1), edgecolor(2), edgecolor(3));
+            int ic = i % Nedgecolors;
+            gc.color = agg::rgba(edgecolors(ic, 0), edgecolors(ic, 1), edgecolors(ic, 2), edgecolors(ic, 3));
 
             if (Nlinewidths) {
                 gc.linewidth = linewidths(i % Nlinewidths);
@@ -1014,7 +1009,7 @@ inline void RendererAgg::_draw_path_collection_generic(GCAgg &gc,
 
             transformed_path_t tpath(path, trans);
             nan_removed_t nan_removed(tpath, true, has_curves);
-            clipped_t clipped(nan_removed, do_clip, width, height);
+            clipped_t clipped(nan_removed, do_clip && !has_curves, width, height);
             snapped_t snapped(
                 clipped, gc.snap_mode, path.total_vertices(), points_to_pixels(gc.linewidth));
             if (has_curves) {
@@ -1153,8 +1148,8 @@ class QuadMeshGenerator
 template <class CoordinateArray, class OffsetArray, class ColorArray>
 inline void RendererAgg::draw_quad_mesh(GCAgg &gc,
                                         agg::trans_affine &master_transform,
-                                        size_t mesh_width,
-                                        size_t mesh_height,
+                                        unsigned int mesh_width,
+                                        unsigned int mesh_height,
                                         CoordinateArray &coordinates,
                                         OffsetArray &offsets,
                                         agg::trans_affine &offset_trans,
@@ -1274,8 +1269,8 @@ inline void RendererAgg::draw_gouraud_triangles(GCAgg &gc,
     bool has_clippath = render_clippath(gc.clippath.path, gc.clippath.trans);
 
     for (int i = 0; i < points.dim(0); ++i) {
-        typename PointArray::sub_t point = points[i];
-        typename ColorArray::sub_t color = colors[i];
+        typename PointArray::sub_t point = points.subarray(i);
+        typename ColorArray::sub_t color = colors.subarray(i);
 
         _draw_gouraud_triangle(point, color, trans, has_clippath);
     }
