@@ -441,7 +441,7 @@ static PyObject *Py_affine_transform(PyObject *self, PyObject *args, PyObject *k
         numpy::array_view<double, 2> result(dims);
         CALL_CPP("affine_transform", (affine_transform_2d(vertices, trans, result)));
         return result.pyobj();
-    } catch (py::exception) {
+    } catch (py::exception &) {
         PyErr_Clear();
         try {
             numpy::array_view<double, 1> vertices(vertices_obj);
@@ -449,7 +449,7 @@ static PyObject *Py_affine_transform(PyObject *self, PyObject *args, PyObject *k
             numpy::array_view<double, 1> result(dims);
             CALL_CPP("affine_transform", (affine_transform_1d(vertices, trans, result)));
             return result.pyobj();
-        } catch (py::exception) {
+        } catch (py::exception &) {
             return NULL;
         }
     }
