@@ -485,7 +485,7 @@ const char *PyFT2Font_init__doc__ =
     "  style_flags            style flags  (int type); see the ft2font constants\n"
     "  num_glyphs             number of glyphs in the face\n"
     "  family_name            face family name\n"
-    "  style_name             face syle name\n"
+    "  style_name             face style name\n"
     "  num_fixed_sizes        number of bitmap in the face\n"
     "  scalable               face is scalable\n"
     "\n"
