@@ -25,9 +25,9 @@ description of that system. In the `Transformation Object` column,
 |           |                             |controlled by xlim and ylim.       |
 +-----------+-----------------------------+-----------------------------------+
 |"axes"     |``ax.transAxes``             |The coordinate system of the       |
-|           |                             |`.Axes`; (0, 0) is bottom left of  |
-|           |                             |the axes, and (1, 1) is top right  |
-|           |                             |of the axes.                       |
+|           |                             |`~matplotlib.axes.Axes`; (0, 0)    |
+|           |                             |is bottom left of the axes, and    |
+|           |                             |(1, 1) is top right of the axes.   |
 +-----------+-----------------------------+-----------------------------------+
 |"figure"   |``fig.transFigure``          |The coordinate system of the       |
 |           |                             |`.Figure`; (0, 0) is bottom left   |
@@ -75,8 +75,7 @@ import matplotlib.pyplot as plt
 x = np.arange(0, 10, 0.005)
 y = np.exp(-x/2.) * np.sin(2*np.pi*x)
 
-fig = plt.figure()
-ax = fig.add_subplot(111)
+fig, ax = plt.subplots()
 ax.plot(x, y)
 ax.set_xlim(0, 10)
 ax.set_ylim(-1, 1)
@@ -124,8 +123,7 @@ plt.show()
 x = np.arange(0, 10, 0.005)
 y = np.exp(-x/2.) * np.sin(2*np.pi*x)
 
-fig = plt.figure()
-ax = fig.add_subplot(111)
+fig, ax = plt.subplots()
 ax.plot(x, y)
 ax.set_xlim(0, 10)
 ax.set_ylim(-1, 1)
@@ -231,8 +229,8 @@ plt.show()
 
 import matplotlib.patches as patches
 
-fig = plt.figure()
-ax = fig.add_subplot(111)
+fig, ax = plt.subplots()
+
 x, y = 10*np.random.rand(2, 1000)
 ax.plot(x, y, 'go')  # plot some data in data coordinates
 
@@ -242,7 +240,7 @@ ax.add_patch(circ)
 plt.show()
 
 ###############################################################################
-# .. blended_transformations:
+# .. _blended_transformations:
 #
 # Blended transformations
 # =======================
@@ -265,9 +263,7 @@ plt.show()
 
 import matplotlib.transforms as transforms
 
-fig = plt.figure()
-ax = fig.add_subplot(111)
-
+fig, ax = plt.subplots()
 x = np.random.randn(1000)
 
 ax.hist(x, 30)
@@ -303,7 +299,7 @@ plt.show()
 #
 #     trans = ax.get_xaxis_transform()
 #
-# .. offset-transforms-shadow:
+# .. _offset-transforms-shadow:
 #
 # Using offset transforms to create a shadow effect
 # =================================================
@@ -371,7 +367,7 @@ ax.set_title('creating a shadow effect with an offset transform')
 plt.show()
 
 ###############################################################################
-# .. transformation-pipeline:
+# .. _transformation-pipeline:
 #
 # The transformation pipeline
 # ===========================
@@ -467,4 +463,4 @@ plt.show()
 # see how to make your own, since Matplotlib supports extensible axes
 # and projections.  Michael Droettboom has provided a nice tutorial
 # example of creating a Hammer projection axes; see
-# :ref:`sphx_glr_gallery_api_custom_projection_example.py`.
+# :doc:`/gallery/misc/custom_projection`.
