@@ -220,8 +220,7 @@ plt.show()
 
 x = np.arange(0, 10, 0.2)
 y = np.sin(x)
-fig = plt.figure()
-ax = fig.add_subplot(111)
+fig, ax = plt.subplots()
 ax.plot(x, y)
 plt.show()
 
@@ -317,7 +316,7 @@ my_plotter(ax2, data3, data4, {'marker': 'o'})
 #
 #
 # #. The ``backend`` parameter in your ``matplotlibrc`` file (see
-#    :ref:`sphx_glr_tutorials_introductory_customizing.py`)::
+#    :doc:`/tutorials/introductory/customizing`)::
 #
 #        backend : WXAgg   # use wxpython with antigrain (agg) rendering
 #
@@ -515,7 +514,7 @@ my_plotter(ax2, data3, data4, {'marker': 'o'})
 # that are called, and on a state variable that determines whether
 # matplotlib is in "interactive mode".  The default Boolean value is set
 # by the :file:`matplotlibrc` file, and may be customized like any other
-# configuration parameter (see :ref:`sphx_glr_tutorials_introductory_customizing.py`).  It
+# configuration parameter (see :doc:`/tutorials/introductory/customizing`).  It
 # may also be set via :func:`matplotlib.interactive`, and its
 # value may be queried via :func:`matplotlib.is_interactive`.  Turning
 # interactive mode on and off in the middle of a stream of plotting
@@ -661,7 +660,7 @@ for i in range(3):
 # controlled by the ``path.simplify`` and
 # ``path.simplify_threshold`` parameters in your
 # ``matplotlibrc`` file (see
-# :ref:`sphx_glr_tutorials_introductory_customizing.py` for
+# :doc:`/tutorials/introductory/customizing` for
 # more information about the ``matplotlibrc`` file).
 # The ``path.simplify`` parameter is a boolean indicating whether
 # or not line segments are simplified at all. The
@@ -698,7 +697,7 @@ for i in range(3):
 # interactive plotting (with maximal simplification) and another
 # style for publication quality plotting (with minimal
 # simplification) and activate them as necessary. See
-# :ref:`sphx_glr_tutorials_introductory_customizing.py` for
+# :doc:`/tutorials/introductory/customizing` for
 # instructions on how to perform these actions.
 #
 # The simplification works by iteratively merging line segments
@@ -729,7 +728,7 @@ for i in range(3):
 #
 # The markevery argument allows for naive subsampling, or an
 # attempt at evenly spaced (along the *x* axis) sampling. See the
-# :ref:`sphx_glr_gallery_lines_bars_and_markers_markevery_demo.py`
+# :doc:`/gallery/lines_bars_and_markers/markevery_demo`
 # for more information.
 #
 # Splitting lines into smaller chunks
