@@ -1,4 +1,4 @@
-"""
+r"""
 Annotations
 ===========
 
@@ -94,7 +94,7 @@ keyword args like ``horizontalalignment``, ``verticalalignment`` and
 
 For more on all the wild and wonderful things you can do with
 annotations, including fancy arrows, see :ref:`plotting-guide-annotation`
-and :ref:`sphx_glr_gallery_text_labels_and_annotations_annotation_demo.py`.
+and :doc:`/gallery/text_labels_and_annotations/annotation_demo`.
 
 
 Do not proceed unless you have already read :ref:`annotations-tutorial`,
@@ -514,13 +514,13 @@ more control, it supports a few other options.
        Annotation with Simple Coordinates 3
 
     You may take a look at this example
-    :ref:`sphx_glr_gallery_text_labels_and_annotations_annotation_demo.py`.
+    :doc:`/gallery/text_labels_and_annotations/annotation_demo`.
 
-Using ConnectorPatch
---------------------
+Using ConnectionPatch
+---------------------
 
-The ConnectorPatch is like an annotation without text. While the annotate
-function is recommended in most situations, the ConnectorPatch is useful when
+The ConnectionPatch is like an annotation without text. While the annotate
+function is recommended in most situations, the ConnectionPatch is useful when
 you want to connect points in different axes. ::
 
   from matplotlib.patches import ConnectionPatch
@@ -540,7 +540,7 @@ point xy in the data coordinates of ``ax2``. Here is a simple example.
    Connect Simple01
 
 
-While the ConnectorPatch instance can be added to any axes, you may want to add
+While the ConnectionPatch instance can be added to any axes, you may want to add
 it to the axes that is latest in drawing order to prevent overlap by other
 axes.
 
